SystemOrganization addCategory: #ContactManager!

Object subclass: #Contact
	instanceVariableNames: 'firstName lastName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContactManager'!

Contact class
	instanceVariableNames: 'database'!

!Contact commentStamp: 'estelle 2/3/2011 08:08' prior: 0!
I have informations about people. I can store created instances.

|someone|
someone := Contact new firstName: 'Miles'; lastName:'Davis'.
Contact database add: someone.

self assert: Contact database last firstName = 'Miles'.
self assert: Contact database last lastName = 'Davis'.!

Contact class
	instanceVariableNames: 'database'!

!Contact class methodsFor: 'accessing' stamp: 'LaurentLaffont 1/22/2011 18:12'!
database
	^ database ifNil: [database := OrderedCollection new]! !

!Contact class methodsFor: 'accessing' stamp: 'NickPapoulias 10/23/2014 14:26'!
database: anOrderedCollection
	database := anOrderedCollection! !

!Contact methodsFor: 'accessing' stamp: 'LaurentLaffont 1/23/2011 10:20'!
firstName
	^ firstName ifNil: [firstName := 'unknown']! !

!Contact methodsFor: 'accessing' stamp: 'LaurentLaffont 1/22/2011 18:11'!
firstName: anObject
	firstName := anObject! !

!Contact methodsFor: 'accessing' stamp: 'LaurentLaffont 1/23/2011 10:19'!
lastName
	^ lastName ifNil: [lastName := 'unknown']! !

!Contact methodsFor: 'accessing' stamp: 'LaurentLaffont 1/22/2011 18:11'!
lastName: anObject
	lastName := anObject! !

!Contact methodsFor: 'printing' stamp: 'LaurentLaffont 1/22/2011 18:15'!
printOn: aStream
	aStream
		nextPutAll: self className;
		nextPutAll: '(';
		nextPutAll: self firstName;
		nextPutAll: ' ';
		nextPutAll: self lastName;
		nextPutAll: ')'.! !

Object subclass: #ContactEditor
	instanceVariableNames: 'contact onOKAction'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContactManager'!

!ContactEditor commentStamp: 'estelle 2/3/2011 08:06' prior: 0!
Dialog to edit a Contact. For example:

ContactEditor new
	contact: (Contact new firstName: 'Miles'; lastName:'Davis');
	openModal.!

!ContactEditor methodsFor: 'accessing' stamp: 'LaurentLaffont 1/23/2011 10:08'!
contact: aContact 
	contact := aContact! !

!ContactEditor methodsFor: 'ok actions' stamp: 'LaurentLaffont 1/23/2011 13:50'!
doOnOK
	^ self onOK value! !

!ContactEditor methodsFor: 'ok actions' stamp: 'LaurentLaffont 1/23/2011 13:50'!
onOK
	^ onOKAction ifNil: [onOKAction := []].! !

!ContactEditor methodsFor: 'ok actions' stamp: 'LaurentLaffont 1/23/2011 13:50'!
onOK: aBlock
	onOKAction := aBlock! !

!ContactEditor methodsFor: 'open/close' stamp: 'LaurentLaffont 1/25/2011 21:15'!
openModal
	|builder dialog content firstName|
 
	builder := UITheme builder.
 	content := (builder newLabelGroup: {
  			'First name' -> (firstName := (builder
   											newTextEntryFor: contact 
											getText: #firstName 
											setText: #firstName: 
											help: 'Enter the first name of the contact')
   										acceptOnCR: false;
   										minWidth: 200).
  			'Last name' -> ((builder
   							newTextEntryFor: contact 
							getText: #lastName 
							setText: #lastName: 
							help: 'Enter the last name of the contact')
   						acceptOnCR: false;
   						minWidth: 200) 
	}).
 
	dialog := builder newPluggableDialogWindow:'Edit contact' for: content.
	dialog rememberKeyboardFocus: firstName.
	builder openModal: dialog.
 
	dialog cancelled ifFalse: [self doOnOK].! !

Object subclass: #ContactListEditor
	instanceVariableNames: 'selectedContactIndex'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContactManager'!

!ContactListEditor commentStamp: 'estelle 2/3/2011 08:03' prior: 0!
Window to add / remove / edit a list of Contact.

Open with 

ContactListEditor new open.!

!ContactListEditor class methodsFor: 'menu' stamp: 'LaurentLaffont 1/28/2011 21:38'!
menuCommandOn: aBuilder 
	<worldMenu> 
	(aBuilder item: #'Manage contacts')
			action:[ self open].! !

!ContactListEditor class methodsFor: 'instance creation' stamp: 'LaurentLaffont 1/23/2011 11:10'!
open
	^ self new open.! !

!ContactListEditor methodsFor: 'callback' stamp: 'LaurentLaffont 1/25/2011 21:23'!
addButtonClick
	|newContact|
	newContact := Contact new.
	
	ContactEditor new
		contact: newContact;
		onOK: [	Contact database add: newContact.  
				selectedContactIndex := Contact database size.
				self 
					changed: #contacts;
					changed: #hasSelectedContact];
		openModal.
		
	! !

!ContactListEditor methodsFor: 'accessing' stamp: 'LaurentLaffont 1/25/2011 21:17'!
contactSelectedIndex
	^ selectedContactIndex ifNil: [selectedContactIndex := 0]! !

!ContactListEditor methodsFor: 'callback' stamp: 'LaurentLaffont 1/25/2011 21:17'!
contactSelectedIndex: aSmallInteger 
	selectedContactIndex := aSmallInteger.
	self 
		changed: #contactSelectedIndex;
  		changed: #hasSelectedContact! !

!ContactListEditor methodsFor: 'accessing' stamp: 'LaurentLaffont 1/23/2011 14:07'!
contacts
	^ Contact database collect: [:aContact| 
		', ' join: {aContact lastName.  aContact firstName}
	].! !

!ContactListEditor methodsFor: 'callback' stamp: 'LaurentLaffont 1/28/2011 21:39'!
editButtonClick
	ContactEditor new
		contact: (Contact database at: selectedContactIndex);
		openModal.
		
	self changed: #contacts.! !

!ContactListEditor methodsFor: 'accessing' stamp: 'LaurentLaffont 1/25/2011 21:18'!
hasSelectedContact
	^selectedContactIndex > 0! !

!ContactListEditor methodsFor: 'open/close' stamp: 'LaurentLaffont 1/28/2011 21:49'!
open
|builder content|
builder := UITheme builder.
content := builder newColumn: {   
	builder 
		newListFor: self   
		list: #contacts
		selected: #contactSelectedIndex
		changeSelected: #contactSelectedIndex:
		help: 'contacts'.
	builder newRow: {
		builder	newButtonFor: self 
								action: #addButtonClick 
								label: 'Add' 
								help: 'Create a new contact'.
		builder newButtonFor: self 
								action: #removeButtonClick 
								getEnabled: #hasSelectedContact 
								label: 'Remove' 
								help: 'Remove selected contact'.
		builder newButtonFor: self 
								action: #editButtonClick 
								getEnabled: #hasSelectedContact 
								label: 'Edit' 
								help: 'Edit selected contact'  }}.
								
(content openInWindowLabeled: 'Contacts') extent: 400@500.! !

!ContactListEditor methodsFor: 'callback' stamp: 'LaurentLaffont 1/25/2011 21:21'!
removeButtonClick
	
	[Contact database removeAt: selectedContactIndex]
		on: Error 
		do: [UITheme builder alert: 'Cannot remove selected contact.'].
		
	self
  		contactSelectedIndex: (self contactSelectedIndex min: Contact database size);
  		changed: #contacts  ! !
